Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/bmi160_simpletest.py
    :caption: examples/bmi160_simpletest.py
    :linenos:

Acceleration Data Range
------------------------

Example showing how to change the acceleration data range

.. literalinclude:: ../examples/bmi160_acce_datarange.py
    :caption: examples/bmi160_acce_datarange.py
    :linenos:

Acceleration Data Rate
------------------------

Example showing how to change the acceleration data rate

.. literalinclude:: ../examples/bmi160_acc_datarate.py
    :caption: examples/bmi160_acc_datarate.py
    :linenos:
